@@ -1,7 +1,5 @@
-from datetime import datetime
-import iso8601
+from annotator import authz, document, es
 
-from annotator import es, authz
 from flask import current_app, g
 
 TYPE = 'annotation'
@@ -32,6 +30,9 @@ MAPPING = {
             'delete': {'type': 'string', 'index': 'not_analyzed'},
             'admin':  {'type': 'string', 'index': 'not_analyzed'}
         }
+    },
+    'document': {
+        'properties': document.MAPPING
     }
 }
 
@@ -40,6 +41,29 @@ class Annotation(es.Model):
     __type__ = TYPE
     __mapping__ = MAPPING
 
+    def save(self, *args, **kwargs):
+        _add_default_permissions(self)
+
+        # If the annotation includes document metadata look to see if we have 
+        # the document modeled already. If we don't we'll create a new one
+        # If we do then we'll merge the supplied links into it.
+
+        if self.has_key("document"):
+            d = self["document"]
+            uris = [link["href"] for link in d['link']]
+            docs = document.Document.get_all_by_uris(uris)
+
+            if len(docs) == 0:
+                doc = document.Document(d)
+                doc.save()
+            else:
+                doc = docs[0]
+                links = d.get('link', [])
+                doc.merge_links(links)
+                doc.save()
+
+        super(Annotation, self).save(*args, **kwargs)
+
     @classmethod
     def _build_query(cls, offset=0, limit=20, **kwargs):
         q = super(Annotation, cls)._build_query(offset, limit, **kwargs)
@@ -50,6 +74,24 @@ class Annotation(es.Model):
                 return False # Refuse to perform the query
             q['query'] = {'filtered': {'query': q['query'], 'filter': f}}
 
+        
+        # attempt to expand query to include uris for other representations
+        # using information we may have on hand about the Document 
+
+        if kwargs.has_key('uri'):
+            doc = document.Document.get_by_uri(kwargs['uri'])
+            if doc:
+                new_terms = []
+                terms = q['query']['filtered']['query']['filtered']['filter']['and']
+                for term in terms:
+                    if term['term'].has_key('uri'):
+                        term = {"or": []}
+                        for uri in doc.uris():
+                            term["or"].append({"term": {"uri": uri}})
+                    new_terms.append(term)
+
+                q['query']['filtered']['query']['filtered']['filter']['and'] = new_terms
+
         return q
 
     @classmethod
@@ -64,24 +106,6 @@ class Annotation(es.Model):
 
         return q, p
 
-    def save(self, *args, **kwargs):
-        # For brand new annotations
-        _add_created(self)
-        _add_default_permissions(self)
-
-        # For all annotations about to be saved
-        _add_updated(self)
-
-        super(Annotation, self).save(*args, **kwargs)
-
-
-def _add_created(ann):
-    if 'created' not in ann:
-        ann['created'] = datetime.now(iso8601.iso8601.UTC).isoformat()
-
-def _add_updated(ann):
-    ann['updated'] = datetime.now(iso8601.iso8601.UTC).isoformat()
-
 def _add_default_permissions(ann):
     if 'permissions' not in ann:
         ann['permissions'] = {'read': [authz.GROUP_CONSUMER]}
