@@ -1,7 +1,7 @@
 import os
 from flask import Flask, g, request
 
-from annotator import es, auth, authz, annotation, store
+from annotator import es, auth, authz, annotation, store, document
 
 from .helpers import MockUser, MockConsumer
 
@@ -22,18 +22,33 @@ def create_app():
 
     return app
 
+
+# pyes 0.19.1 has a bug where cluster.health sends the arguments in
+# a JSON request body instead of as query parameters. The fix is
+# already upstream, but here's a workaround for now. Remove this once
+# a new pyes is released and the dependency version is updated in
+# annotator-store.
+def wait_for_status(conn, level='yellow'):
+    params = dict(wait_for_status=level)
+    conn._send_request('GET', '/_cluster/health', params=params)
+
+
 class TestCase(object):
     @classmethod
     def setup_class(cls):
         cls.app = create_app()
         with cls.app.app_context():
             annotation.Annotation.drop_all()
+            document.Document.drop_all()
 
     def setup(self):
         with self.app.app_context():
             annotation.Annotation.create_all()
+            document.Document.create_all()
         self.cli = self.app.test_client()
+        wait_for_status(es.get_conn(self.app))
 
     def teardown(self):
         with self.app.app_context():
             annotation.Annotation.drop_all()
+            document.Document.drop_all()
